## Summary

- what changed
- why it changed

## Validation

- [ ] `uv run ruff check .`
- [ ] `uv run pytest`
- [ ] `uv build`

## Notes

- config or output changes
- docs changes
- compatibility or migration concerns
